@@ -257,6 +257,7 @@ pub(crate) fn get_cpu_frequency(cpu_core_index: usize) -> u64 {
         .unwrap_or_default()
 }
 
+#[allow(unused_assignments)]
 pub(crate) fn get_physical_core_count() -> Option<usize> {
     let mut s = String::new();
     if let Err(_e) = File::open("/proc/cpuinfo").and_then(|mut f| f.read_to_string(&mut s)) {
@@ -264,11 +265,37 @@ pub(crate) fn get_physical_core_count() -> Option<usize> {
         return None;
     }
 
+    macro_rules! add_core {
+        ($core_ids_and_physical_ids:ident, $core_id:ident, $physical_id:ident, $processor:ident) => {{
+            if !$core_id.is_empty() && !$physical_id.is_empty() {
+                $core_ids_and_physical_ids.insert(format!("{} {}", $core_id, $physical_id));
+            } else if !$processor.is_empty() {
+                // On systems with only physical cores like raspberry, there is no "core id" or
+                // "physical id" fields. So if one of them is missing, we simply use the "processor"
+                // info and count it as a physical core.
+                $core_ids_and_physical_ids.insert($processor.to_owned());
+            }
+            $core_id = "";
+            $physical_id = "";
+            $processor = "";
+        }};
+    }
+
     let mut core_ids_and_physical_ids: HashSet<String> = HashSet::new();
     let mut core_id = "";
     let mut physical_id = "";
+    let mut processor = "";
+
     for line in s.lines() {
-        if line.starts_with("core id") {
+        if line.is_empty() {
+            add_core!(core_ids_and_physical_ids, core_id, physical_id, processor);
+        } else if line.starts_with("processor") {
+            processor = line
+                .splitn(2, ':')
+                .last()
+                .map(|x| x.trim())
+                .unwrap_or_default();
+        } else if line.starts_with("core id") {
             core_id = line
                 .splitn(2, ':')
                 .last()
@@ -281,12 +308,8 @@ pub(crate) fn get_physical_core_count() -> Option<usize> {
                 .map(|x| x.trim())
                 .unwrap_or_default();
         }
-        if !core_id.is_empty() && !physical_id.is_empty() {
-            core_ids_and_physical_ids.insert(format!("{} {}", core_id, physical_id));
-            core_id = "";
-            physical_id = "";
-        }
     }
+    add_core!(core_ids_and_physical_ids, core_id, physical_id, processor);
 
     Some(core_ids_and_physical_ids.len())
 }
