@@ -178,10 +178,7 @@ unsafe fn get_exe(process_handler: HANDLE, h_mod: *mut c_void) -> PathBuf {
 impl Process {
     pub(crate) fn new_from_pid(pid: Pid, now: u64) -> Option<Process> {
         unsafe {
-            let process_handler = OpenProcess(PROCESS_QUERY_INFORMATION, FALSE, pid.0 as _);
-            if process_handler.is_null() {
-                return None;
-            }
+            let process_handler = get_process_handler(pid)?;
             let mut info: MaybeUninit<PROCESS_BASIC_INFORMATION> = MaybeUninit::uninit();
             if NtQueryInformationProcess(
                 process_handler,
@@ -195,16 +192,53 @@ impl Process {
                 return None;
             }
             let info = info.assume_init();
-            Some(Process::new_with_handle(
+            let mut h_mod = null_mut();
+
+            let name = if get_h_mod(process_handler, &mut h_mod) {
+                get_process_name(process_handler, h_mod)
+            } else {
+                String::new()
+            };
+
+            let exe = get_exe(process_handler, h_mod);
+            let mut root = exe.clone();
+            root.pop();
+            let (cmd, environ, cwd) = match get_process_params(process_handler) {
+                Ok(args) => args,
+                Err(_e) => {
+                    sysinfo_debug!("Failed to get process parameters: {}", _e);
+                    (Vec::new(), Vec::new(), PathBuf::new())
+                }
+            };
+            let (start_time, run_time) = get_start_and_run_time(process_handler, now);
+            let parent = if info.InheritedFromUniqueProcessId as usize != 0 {
+                Some(Pid(info.InheritedFromUniqueProcessId as _))
+            } else {
+                None
+            };
+            Some(Process {
+                handle: PtrWrapper(process_handler),
+                name,
                 pid,
-                if info.InheritedFromUniqueProcessId as usize != 0 {
-                    Some(Pid(info.InheritedFromUniqueProcessId as _))
-                } else {
-                    None
-                },
-                process_handler,
-                now,
-            ))
+                parent,
+                cmd,
+                environ,
+                exe,
+                cwd,
+                root,
+                status: ProcessStatus::Run,
+                memory: 0,
+                virtual_memory: 0,
+                cpu_usage: 0.,
+                cpu_calc_values: CPUsageCalculationValues::new(),
+                start_time,
+                run_time,
+                updated: true,
+                old_read_bytes: 0,
+                old_written_bytes: 0,
+                read_bytes: 0,
+                written_bytes: 0,
+            })
         }
     }
 
@@ -220,8 +254,11 @@ impl Process {
             let mut h_mod = null_mut();
 
             unsafe {
-                get_h_mod(handle, &mut h_mod);
-                let exe = get_exe(handle, h_mod);
+                let exe = if get_h_mod(handle, &mut h_mod) {
+                    get_exe(handle, h_mod)
+                } else {
+                    PathBuf::new()
+                };
                 let mut root = exe.clone();
                 root.pop();
                 let (cmd, environ, cwd) = match get_process_params(handle) {
@@ -283,58 +320,6 @@ impl Process {
         }
     }
 
-    fn new_with_handle(
-        pid: Pid,
-        parent: Option<Pid>,
-        process_handler: HANDLE,
-        now: u64,
-    ) -> Process {
-        let mut h_mod = null_mut();
-
-        unsafe {
-            let name = if get_h_mod(process_handler, &mut h_mod) {
-                get_process_name(process_handler, h_mod)
-            } else {
-                String::new()
-            };
-
-            let exe = get_exe(process_handler, h_mod);
-            let mut root = exe.clone();
-            root.pop();
-            let (cmd, environ, cwd) = match get_process_params(process_handler) {
-                Ok(args) => args,
-                Err(_e) => {
-                    sysinfo_debug!("Failed to get process parameters: {}", _e);
-                    (Vec::new(), Vec::new(), PathBuf::new())
-                }
-            };
-            let (start_time, run_time) = get_start_and_run_time(process_handler, now);
-            Process {
-                handle: PtrWrapper(process_handler),
-                name,
-                pid,
-                parent,
-                cmd,
-                environ,
-                exe,
-                cwd,
-                root,
-                status: ProcessStatus::Run,
-                memory: 0,
-                virtual_memory: 0,
-                cpu_usage: 0.,
-                cpu_calc_values: CPUsageCalculationValues::new(),
-                start_time,
-                run_time,
-                updated: true,
-                old_read_bytes: 0,
-                old_written_bytes: 0,
-                read_bytes: 0,
-                written_bytes: 0,
-            }
-        }
-    }
-
     pub(crate) fn update(
         &mut self,
         refresh_kind: crate::ProcessRefreshKind,
